export declare class EventBus {
    constructor(events?: any);
    private _ctx_;
    private _events_;
    /**
     * subscribe to event
     *
     * @param {string} event
     * @param {Function} cb
     * @return {*}
     * @memberof EventBus
     */
    on(event: string, cb: Function): Function;
    /**
     * unsubscribe to event
     *
     * if callback is provided, then only callback is removed otherwise all events subscriber for that event
     *
     * @param {string} event
     * @param {Function} eventListener
     * @memberof EventBus
     */
    off(event: string, eventListener: Function): void;
    eachEvent(events: Map<Function, any>, cb: any): void;
    emitAll(event: string, ...args: any[]): void;
    /**
     * emit event to all listener at a time
     *
     * @param {string} event
     * @param {*} args
     * @return {*}
     * @memberof EventBus
     */
    emit(event: string, ...args: any[]): Promise<any[]>;
    /**
     * linearly calls events - in case of async: wait for one's completion and then call next
     *
     * @param {string} event
     * @param {*} args
     * @return {*}
     * @memberof EventBus
     */
    emitLinear(event: string, ...args: any[]): Promise<any[]>;
    destroy(): void;
    getEvent(eventName: string): Map<Function, boolean>;
}
